
import os
import click


TEMPLATE_URL = 'https://github.com/connormullett/FlaskBoilerPlate.git'


@click.group()
def main():
    pass

@main.command()
def start():

    project_name = click.prompt('Enter project name')

    path = os.getcwd()
    if click.confirm('User Authentication?'):
        os.system('git clone %s %s/%s' % (TEMPLATE_URL, path, project_name))

    else:
        os.system('git clone %s --branch no-auth %s/%s' % (TEMPLATE_URL, path, project_name))





import os
from setuptools import setup


def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()


setup(
    name='FlaskIt-starter',
    author='Connor Mullett',
    description='Flask API starter',
    long_description=read('README.rst'),
    keywords='flask api',
    packages=['src'],
    license='MIT',
    install_requires=[
        'click'
    ],
    version='1.0.0',
    url='https://github.com/connormullett/FlaskIt',
    download_url='https://github.com/connormullett/FlaskIt/archive/v1.0.tar.gz',
    entry_points={
        'console_scripts':
            'flaskit-starter=src.main:main'
    }
)

